@@ -56,7 +56,7 @@ def load_module(module_name, module_path):
 def _map_parallel(function, args, n_jobs):
     """multiprocessing.Pool(processors=n_jobs).map with some error checking"""
     # Following the error checking found in joblib
-    multiprocessing = int(n_jobs) not in (0, 1)
+    multiprocessing = int(os.environ.get('JOBLIB_MULTIPROCESSING', 1)) or None
     if multiprocessing:
         try:
             import multiprocessing
@@ -72,7 +72,7 @@ def _map_parallel(function, args, n_jobs):
         except (ImportError, OSError) as e:
             multiprocessing = None
             warnings.warn('%s. _map_parallel will operate in serial mode' % (e,))
-    if multiprocessing:
+    if multiprocessing and int(n_jobs) not in (0, 1):
         if n_jobs == -1:
             n_jobs = None
         mymap = multiprocessing.Pool(processes=n_jobs).map
@@ -256,7 +256,7 @@ class StanModel:
                         os.path.join(pystan_dir, "stan/src"),
                         os.path.join(pystan_dir, "stan/lib/eigen_3.2.0"),
                         os.path.join(pystan_dir, "stan/lib/boost_1.54.0")]
-        library_dirs = [os.path.join(pystan_dir, "bin")]
+        library_dirs = [os.path.join(pystan_dir)]
         libraries = ['stan']
 
         if not os.path.exists(lib_dir):
@@ -389,12 +389,15 @@ class StanModel:
             ``random.randint(0, MAX_UINT)``.
 
         init : {0, '0', 'random', function returning dict, list of dict}, optional
-            Specifies how initial parameter values are chosen: 0 or '0'
-            initializes all to be zero on the unconstrained support; 'random'
-            generates random initial values; list of size equal to the number
-            of chains (`chains`), where the list contains a dict with initial
-            parameter values; function returning a dict with initial parameter
-            values. The function may take an optional argument `chain_id`.
+            Specifies how initial parameter values are chosen:
+            - 0 or '0' initializes all to be zero on the unconstrained support.
+            - 'random' generates random initial values. An optional parameter
+                `init_r` controls the range of randomly generated initial values
+                for parameters in terms of their unconstrained support;
+            - list of size equal to the number of chains (`chains`), where the
+                list contains a dict with initial parameter values;
+            - function returning a dict with initial parameter values. The
+                function may take an optional argument `chain_id`.
 
         sample_file : string, optional
             File name specifying where samples for *all* parameters and other
