@@ -235,6 +235,7 @@ namespace stan {
         return true;
       }
 
+
       /**
        * Print a human readable parsed form of the command-line
        * arguments to the specified output stream.
@@ -267,6 +268,26 @@ namespace stan {
 
     };
 
+    // explicit instantation for std::string to allow for spaces
+    // in bare_[n]
+    template <>
+    bool cmd_line::bare<std::string>(size_t n, std::string& x) const {
+      if (n >= bare_.size())
+        return false;
+      x = bare_[n];
+      return true;
+    }
+
+    // explicit instantation for std::string to allow for spaces
+    // in key_val_
+    template <>
+    bool cmd_line::val<std::string>(const std::string& key, std::string& x) const {
+      if (!has_key(key))
+        return false;
+      x = key_val_.find(key)->second;
+      return true;
+    }
+
 
   }
 
