@@ -1,14 +1,13 @@
 #ifndef __STAN__IO__MCMC__WRITER__HPP
 #define __STAN__IO__MCMC__WRITER__HPP
 
-#include <iostream>
+#include <ostream>
 #include <iomanip>
-
-#include <vector>
 #include <string>
+#include <vector>
 
-#include <stan/mcmc/sample.hpp>
 #include <stan/mcmc/base_mcmc.hpp>
+#include <stan/mcmc/sample.hpp>
 #include <stan/model/prob_grad.hpp>
 
 namespace stan {
@@ -21,14 +20,18 @@ namespace stan {
     public:
       
       mcmc_writer(std::ostream* sample_stream,
-                  std::ostream* diagnostic_stream): _sample_stream(sample_stream),
-                                                    _diagnostic_stream(diagnostic_stream) {}
+                  std::ostream* diagnostic_stream,
+                  std::ostream* msg_stream = 0)
+        : sample_stream_(sample_stream),
+          diagnostic_stream_(diagnostic_stream),
+          msg_stream_(msg_stream) {
+      }
       
       void print_sample_names(stan::mcmc::sample& sample,
                               stan::mcmc::base_mcmc* sampler,
                               M& model) {
         
-        if(!_sample_stream) return;
+        if (!sample_stream_) return;
         
         std::vector<std::string> names;
         
@@ -36,11 +39,11 @@ namespace stan {
         sampler->get_sampler_param_names(names);
         model.constrained_param_names(names, true, true);
        
-        (*_sample_stream) << names.at(0);
+        (*sample_stream_) << names.at(0);
         for (size_t i = 1; i < names.size(); ++i) {
-          (*_sample_stream) << "," << names.at(i);
+          (*sample_stream_) << "," << names.at(i);
         }
-        (*_sample_stream) << std::endl;
+        (*sample_stream_) << std::endl;
         
       }
 
@@ -50,34 +53,35 @@ namespace stan {
                                stan::mcmc::base_mcmc& sampler,
                                M& model) {
         
-        if(!_sample_stream) return;
+        if (!sample_stream_) return;
         
         std::vector<double> values;
         
         sample.get_sample_params(values);
         sampler.get_sampler_params(values);
         
-        std::vector<double> model_values;
+        Eigen::VectorXd model_values;
         
         model.write_array(rng,
-                          const_cast<std::vector<double>&>(sample.cont_params()),
-                          const_cast<std::vector<int>&>(sample.disc_params()),
+                          const_cast<Eigen::VectorXd&>(sample.cont_params()),
                           model_values,
-                          true, true); // FIXME: add ostream for msgs!
+                          true, true,
+                          msg_stream_); 
+
+        for (int i = 0; i < model_values.size(); ++i)
+          values.push_back(model_values(i));
         
-        values.insert(values.end(), model_values.begin(), model_values.end());
-        
-        (*_sample_stream) << values.at(0);
+        (*sample_stream_) << values.at(0);
         for (size_t i = 1; i < values.size(); ++i) {
-          (*_sample_stream) << "," << values.at(i);
+          (*sample_stream_) << "," << values.at(i);
         }
-        (*_sample_stream) << std::endl;
+        (*sample_stream_) << std::endl;
         
       }
       
       void print_adapt_finish(stan::mcmc::base_mcmc* sampler, std::ostream* stream) {
         
-        if(!stream) return;
+        if (!stream) return;
         
         *stream << "# Adaptation terminated" << std::endl;
         sampler->write_sampler_state(stream);
@@ -85,15 +89,15 @@ namespace stan {
       }
       
       void print_adapt_finish(stan::mcmc::base_mcmc* sampler) {
-        print_adapt_finish(sampler, _sample_stream);
-        print_adapt_finish(sampler, _diagnostic_stream);
+        print_adapt_finish(sampler, sample_stream_);
+        print_adapt_finish(sampler, diagnostic_stream_);
       }
       
       void print_diagnostic_names(stan::mcmc::sample sample,
                                   stan::mcmc::base_mcmc* sampler,
                                   M& model) {
         
-        if(!_diagnostic_stream) return;
+        if (!diagnostic_stream_) return;
         
         std::vector<std::string> names;
         
@@ -105,18 +109,18 @@ namespace stan {
         
         sampler->get_sampler_diagnostic_names(model_names, names);
         
-        (*_diagnostic_stream) << names.at(0);
-        for (size_t i = 1; i < names.size(); ++i) {
-          (*_diagnostic_stream) << "," << names.at(i);
+        for (size_t i = 0; i < names.size(); ++i) {
+          if (i > 0) *diagnostic_stream_ << ",";
+          *diagnostic_stream_ << names.at(i);
         }
-        (*_diagnostic_stream) << std::endl;
+        *diagnostic_stream_ << std::endl;
         
       }
       
       void print_diagnostic_params(stan::mcmc::sample& sample,
                                    stan::mcmc::base_mcmc* sampler) {
         
-        if(!_diagnostic_stream) return;
+        if (!diagnostic_stream_) return;
         
         std::vector<double> values;
         
@@ -124,16 +128,17 @@ namespace stan {
         sampler->get_sampler_params(values);
         sampler->get_sampler_diagnostics(values);
         
-        (*_diagnostic_stream) << values.at(0);
+        (*diagnostic_stream_) << values.at(0);
         for (size_t i = 1; i < values.size(); ++i) {
-          (*_diagnostic_stream) << "," << values.at(i);
+          (*diagnostic_stream_) << "," << values.at(i);
         }
-        (*_diagnostic_stream) << std::endl;
+        (*diagnostic_stream_) << std::endl;
         
       }
       
-      void print_timing(double warmDeltaT, double sampleDeltaT, std::ostream* stream, const char prefix = '\0') {
-        if(!stream) return;
+      void print_timing(double warmDeltaT, double sampleDeltaT, 
+                        std::ostream* stream, const char prefix = '\0') {
+        if (!stream) return;
         
         std::string title(" Elapsed Time: ");
         
@@ -142,21 +147,23 @@ namespace stan {
                 << " seconds (Warm-up)"  << std::endl
                 << prefix << " " << std::string(title.size(), ' ') << sampleDeltaT
                 << " seconds (Sampling)"  << std::endl
-                << prefix << " " << std::string(title.size(), ' ') << warmDeltaT + sampleDeltaT
+                << prefix << " " << std::string(title.size(), ' ') 
+                << warmDeltaT + sampleDeltaT
                 << " seconds (Total)"  << std::endl
                 << std::endl;
       }
       
       void print_timing(double warmDeltaT, double sampleDeltaT) {
-        print_timing(warmDeltaT, sampleDeltaT, _sample_stream, '#');
-        print_timing(warmDeltaT, sampleDeltaT, _diagnostic_stream, '#');
+        print_timing(warmDeltaT, sampleDeltaT, sample_stream_, '#');
+        print_timing(warmDeltaT, sampleDeltaT, diagnostic_stream_, '#');
         print_timing(warmDeltaT, sampleDeltaT, &std::cout);
       }
       
     private:
       
-      std::ostream* _sample_stream;
-      std::ostream* _diagnostic_stream;
+      std::ostream* sample_stream_;
+      std::ostream* diagnostic_stream_;
+      std::ostream* msg_stream_;
       
     };
     
