@@ -6,8 +6,8 @@
 #include <stan/math/error_handling.hpp>
 #include <stan/prob/traits.hpp>
 #include <stan/meta/traits.hpp>
-#include <stan/agrad/agrad.hpp>
-#include <stan/agrad/matrix.hpp>
+#include <stan/agrad/rev.hpp>
+#include <stan/agrad/rev/matrix.hpp>
 #include "stan/prob/distributions/multivariate/continuous/wishart.hpp"
 #include <stan/math/matrix/ldlt.hpp>
 
