@@ -22,15 +22,13 @@ namespace stan {
         _m2.setZero();
       }
       
-      void add_sample(std::vector<double>& q) {
-        
-        Eigen::Map<Eigen::VectorXd> x(&q[0], q.size());
+      void add_sample(const Eigen::VectorXd& q) {
         
         ++_num_samples;
         
-        Eigen::VectorXd delta(x - _m);
+        Eigen::VectorXd delta(q - _m);
         _m  += delta / _num_samples;
-        _m2 += (x - _m) * delta.transpose();
+        _m2 += (q - _m) * delta.transpose();
         
       }
       
