@@ -1,6 +1,6 @@
 #include <stan/agrad/rev/jacobian.hpp>
-#include <stan/agrad/rev/operator_addition.hpp>
-#include <stan/agrad/rev/operator_multiplication.hpp>
+#include <stan/agrad/rev/operators/operator_addition.hpp>
+#include <stan/agrad/rev/operators/operator_multiplication.hpp>
 #include <test/agrad/util.hpp>
 #include <gtest/gtest.h>
 
