@@ -1,4 +1,4 @@
 #include <stan/agrad/rev/matrix/stan_print.hpp>
-#include <stan/agrad/matrix.hpp>
+#include <stan/agrad/rev/matrix.hpp>
 #include <gtest/gtest.h>
 #include <test/agrad/util.hpp>
