@@ -1,5 +1,5 @@
 #include <stan/agrad/rev/var_stack.hpp>
-#include <stan/agrad/rev/operator_multiplication.hpp>
+#include <stan/agrad/rev/operators/operator_multiplication.hpp>
 #include <test/agrad/util.hpp>
 #include <gtest/gtest.h>
 
