@@ -33,16 +33,31 @@ void remove_duplicates(std::string& argument) {
   }
 }
 
-TEST(StanGmArgumentsConfiguration, TestMethod) {
-  
-  // Prepare model
-  std::vector<std::string> model_path;
-  model_path.push_back("src");
-  model_path.push_back("test");
-  model_path.push_back("gm");
-  model_path.push_back("arguments");
-  model_path.push_back("test_model");
-  
+class StanGmArgumentsConfiguration : public testing::Test {
+public:
+  static void SetUpTestCase() {
+    std::vector<std::string> model_path;
+    model_path.push_back("..");
+    model_path.push_back("src");
+    model_path.push_back("test");
+    model_path.push_back("gm");
+    model_path.push_back("arguments");
+    model_path.push_back("test_model");
+
+    command += "cd test ";
+    command += multiple_command_separator();
+    command += " ";
+    command += convert_model_path(model_path);
+  }
+
+  static void TearDownTestCase() {
+  }
+
+  static std::string command;
+};
+std::string StanGmArgumentsConfiguration::command = "";
+
+TEST_F(StanGmArgumentsConfiguration, TestMethod) {
   // Prepare arguments
   std::stringstream s;
   
@@ -90,11 +105,9 @@ TEST(StanGmArgumentsConfiguration, TestMethod) {
       
       remove_duplicates(argument);
 
-      std::string command = convert_model_path(model_path) + argument;
+      SCOPED_TRACE(command + argument);
 
-      SCOPED_TRACE(command);
-
-      run_command_output out = run_command(command);
+      run_command_output out = run_command(command + argument);
 
       expected_output.clear();
       expected_output.seekg(std::ios_base::beg);
@@ -115,7 +128,9 @@ TEST(StanGmArgumentsConfiguration, TestMethod) {
         expected_output << "is not a valid value for" << std::endl;
         expected_output << "Failed to parse arguments, terminating Stan" << std::endl;
         n_output = 2;
+        
         EXPECT_EQ(int(stan::gm::error_codes::USAGE), out.err_code);
+        
       } else {
         EXPECT_EQ(int(stan::gm::error_codes::OK), out.err_code);
       }
@@ -123,13 +138,12 @@ TEST(StanGmArgumentsConfiguration, TestMethod) {
       output.clear();
       output.seekg(std::ios_base::beg);
       output.str(out.output);
+      std::string actual_line;
       
       for (int i = 0; i < n_output; ++i) {
         std::string expected_line;
         std::getline(expected_output, expected_line);
         
-        
-        std::string actual_line;
         std::getline(output, actual_line);
         
         EXPECT_EQ(expected_line, actual_line);
@@ -145,15 +159,7 @@ TEST(StanGmArgumentsConfiguration, TestMethod) {
     delete valid_arguments.at(i);
 }
 
-TEST(StanGmArgumentsConfiguration, TestIdWithMethod) {
-  
-  // Prepare model
-  std::vector<std::string> model_path;
-  model_path.push_back("src");
-  model_path.push_back("test");
-  model_path.push_back("gm");
-  model_path.push_back("arguments");
-  model_path.push_back("test_model");
+TEST_F(StanGmArgumentsConfiguration, TestIdWithMethod) {
   
   // Prepare arguments
   std::stringstream method_output;
@@ -218,8 +224,7 @@ TEST(StanGmArgumentsConfiguration, TestIdWithMethod) {
       remove_duplicates(argument);
       argument = method_argument + argument;
       
-      std::string command = convert_model_path(model_path) + argument;
-      run_command_output out = run_command(command);
+      run_command_output out = run_command(command + argument);
       
       expected_output.clear();
       expected_output.seekg(std::ios_base::beg);
@@ -241,17 +246,15 @@ TEST(StanGmArgumentsConfiguration, TestIdWithMethod) {
       }
     
       output.str(out.output);
+      std::string actual_line;
       
       for (int i = 0; i < n_output; ++i) {
-        
         std::string expected_line;
         std::getline(expected_output, expected_line);
         
-        std::string actual_line;
         std::getline(output, actual_line);
         
         EXPECT_EQ(expected_line, actual_line);
-        
       }
       
       expected_output.clear();
@@ -268,15 +271,7 @@ TEST(StanGmArgumentsConfiguration, TestIdWithMethod) {
 }
 
 
-TEST(StanGmArgumentsConfiguration, TestIdWithoutMethod) {
-  
-  // Prepare model
-  std::vector<std::string> model_path;
-  model_path.push_back("src");
-  model_path.push_back("test");
-  model_path.push_back("gm");
-  model_path.push_back("arguments");
-  model_path.push_back("test_model");
+TEST_F(StanGmArgumentsConfiguration, TestIdWithoutMethod) {
   
   // Prepare arguments
   std::stringstream s;
@@ -321,8 +316,7 @@ TEST(StanGmArgumentsConfiguration, TestIdWithoutMethod) {
       
       remove_duplicates(argument);
       
-      std::string command = convert_model_path(model_path) + argument;
-      run_command_output out = run_command(command);
+      run_command_output out = run_command(command + argument);
       
       expected_output.clear();
       expected_output.seekg(std::ios_base::beg);
@@ -349,17 +343,15 @@ TEST(StanGmArgumentsConfiguration, TestIdWithoutMethod) {
       }
     
       output.str(out.output);
+      std::string actual_line;
       
       for (int i = 0; i < n_output; ++i) {
-        
         std::string expected_line;
         std::getline(expected_output, expected_line);
         
-        std::string actual_line;
         std::getline(output, actual_line);
         
         EXPECT_EQ(expected_line, actual_line);
-        
       }
       
       expected_output.clear();
@@ -375,15 +367,7 @@ TEST(StanGmArgumentsConfiguration, TestIdWithoutMethod) {
   
 }
 
-TEST(StanGmArgumentsConfiguration, TestDataWithMethod) {
-  
-  // Prepare model
-  std::vector<std::string> model_path;
-  model_path.push_back("src");
-  model_path.push_back("test");
-  model_path.push_back("gm");
-  model_path.push_back("arguments");
-  model_path.push_back("test_model");
+TEST_F(StanGmArgumentsConfiguration, TestDataWithMethod) {
   
   // Prepare arguments
   std::stringstream method_output;
@@ -448,8 +432,7 @@ TEST(StanGmArgumentsConfiguration, TestDataWithMethod) {
       remove_duplicates(argument);
       argument = method_argument + argument;
       
-      std::string command = convert_model_path(model_path) + argument;
-      run_command_output out = run_command(command);
+      run_command_output out = run_command(command + argument);
 
       expected_output.clear();
       expected_output.seekg(std::ios_base::beg);
@@ -471,17 +454,15 @@ TEST(StanGmArgumentsConfiguration, TestDataWithMethod) {
       }
       
       output.str(out.output);
+      std::string actual_line;
       
       for (int i = 0; i < n_output; ++i) {
-        
         std::string expected_line;
         std::getline(expected_output, expected_line);
         
-        std::string actual_line;
         std::getline(output, actual_line);
         
         EXPECT_EQ(expected_line, actual_line);
-        
       }
       
       expected_output.clear();
@@ -498,15 +479,7 @@ TEST(StanGmArgumentsConfiguration, TestDataWithMethod) {
 }
 
 
-TEST(StanGmArgumentsConfiguration, TestDataWithoutMethod) {
-  
-  // Prepare model
-  std::vector<std::string> model_path;
-  model_path.push_back("src");
-  model_path.push_back("test");
-  model_path.push_back("gm");
-  model_path.push_back("arguments");
-  model_path.push_back("test_model");
+TEST_F(StanGmArgumentsConfiguration, TestDataWithoutMethod) {
   
   // Prepare arguments
   std::stringstream s;
@@ -550,9 +523,8 @@ TEST(StanGmArgumentsConfiguration, TestDataWithoutMethod) {
       if (argument.length() == 0) continue;
       
       remove_duplicates(argument);
-      
-      std::string command = convert_model_path(model_path) + argument;
-      run_command_output out = run_command(command);
+
+      run_command_output out = run_command(command + argument);
       
       expected_output.clear();
       expected_output.seekg(std::ios_base::beg);
@@ -579,17 +551,15 @@ TEST(StanGmArgumentsConfiguration, TestDataWithoutMethod) {
       }
       
       output.str(out.output);
+      std::string actual_line;
       
       for (int i = 0; i < n_output; ++i) {
-        
         std::string expected_line;
         std::getline(expected_output, expected_line);
         
-        std::string actual_line;
         std::getline(output, actual_line);
         
         EXPECT_EQ(expected_line, actual_line);
-        
       }
       
       expected_output.clear();
@@ -605,15 +575,7 @@ TEST(StanGmArgumentsConfiguration, TestDataWithoutMethod) {
   
 }
 
-TEST(StanGmArgumentsConfiguration, TestInitWithMethod) {
-  
-  // Prepare model
-  std::vector<std::string> model_path;
-  model_path.push_back("src");
-  model_path.push_back("test");
-  model_path.push_back("gm");
-  model_path.push_back("arguments");
-  model_path.push_back("test_model");
+TEST_F(StanGmArgumentsConfiguration, TestInitWithMethod) {
   
   // Prepare arguments
   std::stringstream method_output;
@@ -643,7 +605,6 @@ TEST(StanGmArgumentsConfiguration, TestInitWithMethod) {
   
   stan::gm::argument_probe probe(valid_arguments);
   probe.probe_args(s);
-  
   // Check argument consistency
   bool expected_success = false;
   
@@ -678,8 +639,7 @@ TEST(StanGmArgumentsConfiguration, TestInitWithMethod) {
       remove_duplicates(argument);
       argument = method_argument + argument;
       
-      std::string command = convert_model_path(model_path) + argument;
-      run_command_output out = run_command(command);
+      run_command_output out = run_command(command + argument);
       
       expected_output.clear();
       expected_output.seekg(std::ios_base::beg);
@@ -701,25 +661,19 @@ TEST(StanGmArgumentsConfiguration, TestInitWithMethod) {
       }
       
       output.str(out.output);
+      std::string actual_line;
       
       for (int i = 0; i < n_output; ++i) {
-        
         std::string expected_line;
         std::getline(expected_output, expected_line);
         
-        std::string actual_line;
         std::getline(output, actual_line);
         
         EXPECT_EQ(expected_line, actual_line);
-        
       }
       
-      expected_output.clear();
-      expected_output.seekg(std::ios_base::beg);
-      expected_output.str(std::string());
-      
     }
-    
+      
   }
   
   for (size_t i = 0; i < valid_arguments.size(); ++i)
@@ -728,15 +682,7 @@ TEST(StanGmArgumentsConfiguration, TestInitWithMethod) {
 }
 
 
-TEST(StanGmArgumentsConfiguration, TestInitWithoutMethod) {
-  
-  // Prepare model
-  std::vector<std::string> model_path;
-  model_path.push_back("src");
-  model_path.push_back("test");
-  model_path.push_back("gm");
-  model_path.push_back("arguments");
-  model_path.push_back("test_model");
+TEST_F(StanGmArgumentsConfiguration, TestInitWithoutMethod) {
   
   // Prepare arguments
   std::stringstream s;
@@ -781,8 +727,7 @@ TEST(StanGmArgumentsConfiguration, TestInitWithoutMethod) {
       
       remove_duplicates(argument);
       
-      std::string command = convert_model_path(model_path) + argument;
-      run_command_output out = run_command(command);
+      run_command_output out = run_command(command + argument);
       
       expected_output.clear();
       expected_output.seekg(std::ios_base::beg);
@@ -809,23 +754,17 @@ TEST(StanGmArgumentsConfiguration, TestInitWithoutMethod) {
       }
       
       output.str(out.output);
-      
+      std::string actual_line;
+    
       for (int i = 0; i < n_output; ++i) {
-        
         std::string expected_line;
         std::getline(expected_output, expected_line);
         
-        std::string actual_line;
         std::getline(output, actual_line);
         
         EXPECT_EQ(expected_line, actual_line);
-        
       }
       
-      expected_output.clear();
-      expected_output.seekg(std::ios_base::beg);
-      expected_output.str(std::string());
-      
     }
     
   }
@@ -835,15 +774,7 @@ TEST(StanGmArgumentsConfiguration, TestInitWithoutMethod) {
   
 }
 
-TEST(StanGmArgumentsConfiguration, TestRandomWithMethod) {
-  
-  // Prepare model
-  std::vector<std::string> model_path;
-  model_path.push_back("src");
-  model_path.push_back("test");
-  model_path.push_back("gm");
-  model_path.push_back("arguments");
-  model_path.push_back("test_model");
+TEST_F(StanGmArgumentsConfiguration, TestRandomWithMethod) {
   
   // Prepare arguments
   std::stringstream method_output;
@@ -908,8 +839,7 @@ TEST(StanGmArgumentsConfiguration, TestRandomWithMethod) {
       remove_duplicates(argument);
       argument = method_argument + argument;
       
-      std::string command = convert_model_path(model_path) + argument;
-      run_command_output out = run_command(command);
+      run_command_output out = run_command(command + argument);
       
       expected_output.clear();
       expected_output.seekg(std::ios_base::beg);
@@ -931,23 +861,17 @@ TEST(StanGmArgumentsConfiguration, TestRandomWithMethod) {
       }
       
       output.str(out.output);
+      std::string actual_line;
       
       for (int i = 0; i < n_output; ++i) {
-        
         std::string expected_line;
         std::getline(expected_output, expected_line);
         
-        std::string actual_line;
         std::getline(output, actual_line);
         
         EXPECT_EQ(expected_line, actual_line);
-        
       }
       
-      expected_output.clear();
-      expected_output.seekg(std::ios_base::beg);
-      expected_output.str(std::string());
-      
     }
     
   }
@@ -958,15 +882,7 @@ TEST(StanGmArgumentsConfiguration, TestRandomWithMethod) {
 }
 
 
-TEST(StanGmArgumentsConfiguration, TestRandomWithoutMethod) {
-  
-  // Prepare model
-  std::vector<std::string> model_path;
-  model_path.push_back("src");
-  model_path.push_back("test");
-  model_path.push_back("gm");
-  model_path.push_back("arguments");
-  model_path.push_back("test_model");
+TEST_F(StanGmArgumentsConfiguration, TestRandomWithoutMethod) {
   
   // Prepare arguments
   std::stringstream s;
@@ -1011,8 +927,7 @@ TEST(StanGmArgumentsConfiguration, TestRandomWithoutMethod) {
       
       remove_duplicates(argument);
       
-      std::string command = convert_model_path(model_path) + argument;
-      run_command_output out = run_command(command);
+      run_command_output out = run_command(command + argument);
       
       expected_output.clear();
       expected_output.seekg(std::ios_base::beg);
@@ -1039,17 +954,15 @@ TEST(StanGmArgumentsConfiguration, TestRandomWithoutMethod) {
       }
       
       output.str(out.output);
+      std::string actual_line;
       
       for (int i = 0; i < n_output; ++i) {
-        
         std::string expected_line;
         std::getline(expected_output, expected_line);
         
-        std::string actual_line;
         std::getline(output, actual_line);
         
         EXPECT_EQ(expected_line, actual_line);
-        
       }
       
       expected_output.clear();
@@ -1065,15 +978,7 @@ TEST(StanGmArgumentsConfiguration, TestRandomWithoutMethod) {
   
 }
 
-TEST(StanGmArgumentsConfiguration, TestOutputWithMethod) {
-  
-  // Prepare model
-  std::vector<std::string> model_path;
-  model_path.push_back("src");
-  model_path.push_back("test");
-  model_path.push_back("gm");
-  model_path.push_back("arguments");
-  model_path.push_back("test_model");
+TEST_F(StanGmArgumentsConfiguration, TestOutputWithMethod) {
   
   // Prepare arguments
   std::stringstream method_output;
@@ -1125,7 +1030,7 @@ TEST(StanGmArgumentsConfiguration, TestOutputWithMethod) {
       
       std::string l2;
       std::string argument("");
-      
+
       while (expected_output.good()) {
         std::getline(expected_output, l2);
         if (!expected_output.good()) continue;
@@ -1138,8 +1043,7 @@ TEST(StanGmArgumentsConfiguration, TestOutputWithMethod) {
       remove_duplicates(argument);
       argument = method_argument + argument;
       
-      std::string command = convert_model_path(model_path) + argument;
-      run_command_output out = run_command(command);
+      run_command_output out = run_command(command + argument);
       
       expected_output.clear();
       expected_output.seekg(std::ios_base::beg);
@@ -1161,17 +1065,15 @@ TEST(StanGmArgumentsConfiguration, TestOutputWithMethod) {
       }
       
       output.str(out.output);
+      std::string actual_line;
       
       for (int i = 0; i < n_output; ++i) {
-        
         std::string expected_line;
         std::getline(expected_output, expected_line);
         
-        std::string actual_line;
         std::getline(output, actual_line);
         
         EXPECT_EQ(expected_line, actual_line);
-        
       }
       
       expected_output.clear();
@@ -1188,15 +1090,7 @@ TEST(StanGmArgumentsConfiguration, TestOutputWithMethod) {
 }
 
 
-TEST(StanGmArgumentsConfiguration, TestOutputWithoutMethod) {
-  
-  // Prepare model
-  std::vector<std::string> model_path;
-  model_path.push_back("src");
-  model_path.push_back("test");
-  model_path.push_back("gm");
-  model_path.push_back("arguments");
-  model_path.push_back("test_model");
+TEST_F(StanGmArgumentsConfiguration, TestOutputWithoutMethod) {
   
   // Prepare arguments
   std::stringstream s;
@@ -1241,8 +1135,7 @@ TEST(StanGmArgumentsConfiguration, TestOutputWithoutMethod) {
       
       remove_duplicates(argument);
       
-      std::string command = convert_model_path(model_path) + argument;
-      run_command_output out = run_command(command);
+      run_command_output out = run_command(command + argument);
       
       expected_output.clear();
       expected_output.seekg(std::ios_base::beg);
@@ -1269,17 +1162,15 @@ TEST(StanGmArgumentsConfiguration, TestOutputWithoutMethod) {
       }
       
       output.str(out.output);
+      std::string actual_line;
       
       for (int i = 0; i < n_output; ++i) {
-        
         std::string expected_line;
         std::getline(expected_output, expected_line);
         
-        std::string actual_line;
         std::getline(output, actual_line);
         
         EXPECT_EQ(expected_line, actual_line);
-        
       }
       
       expected_output.clear();
