@@ -27,18 +27,30 @@ def test_array_param():
     beta_mean = np.mean(beta, axis=0)
     assert beta_mean.shape == (4, 1, 2)
     assert np.all(beta_mean[:, 0, 0] < 4)
-    assert np.all(beta_mean[:, 0, 2] > 100 - 4)
+    assert np.all(beta_mean[:, 0, 1] > 100 - 4)
 
     # extract, permuted=False
     extracted = fit.extract(permuted=False)
     assert extracted.shape == (1000, 4, 9)
+    # in theory 0:4 should be
+    # 'beta[0,0,0]'
+    # 'beta[1,0,0]'
+    # 'beta[2,0,0]'
+    # 'beta[3,0,0]'
+    #
+    # and 4:8 should be
+    # 'beta[0,0,1]'
+    # 'beta[1,0,1]'
+    # 'beta[2,0,1]'
+    # 'beta[3,0,1]'
+    assert np.all(np.mean(extracted[:, :, 0:4], axis=(0, 1)) < 4)
+    assert np.all(np.mean(extracted[:, :, 4:8], axis=(0, 1)) > 100 - 4)
+    assert np.all(extracted[:, :, 8] < 0)  # lp__
 
     # optimizing
     sm = fit.stanmodel
     op = sm.optimizing(data=dict(K=4))
-    assert np.mean(extracted[:,:,0:11]) < 4
-    assert np.all(extracted[:,:,12] < 0)  # lp__
     beta = op['par']['beta']
     assert beta.shape == (4, 1, 2)
     assert np.all(beta[:, 0, 0] < 4)
-    assert np.all(beta[:, 0, 2] > 100 - 4)
+    assert np.all(beta[:, 0, 1] > 100 - 4)
